# jsutils api
js工具类
## License
请查看 [MIT license](./LICENSE).

### 数组
** 根据具体值，从数组中移除元素
``` js
import { ArrayUtils } from "great-jsutils/index";
//字符串移除，第一个参数是被操作的数组，第二个参数是需要移除的字符串
testArray(){
    let arr=["a","b","c"];
    ArrayUtils.remove(arr,"b");
    console.log(arr.join(","));//a,c
}
//对象移除，第一个参数是被操作的数组，第二个参数是需要移除的对象，第三个对象的主键
testArray(){
    let objArr=[{"id":"1","name":"赵云"},{"id":"2","name":"诸葛亮"}];
    ArrayUtils.remove(objArr,{"id":"2"},"id");
    console.log(JSON.stringify(objArr));//[{"id":"1","name":"赵云"}]
}
//数组中的对象key替换，例如源数据为[{"name":"张三"}]替换为[{"text":"张三"}]
testArray(){
    let datas=[{"name":"张三","sex":"1"}];
    let keys={"name":"text"};
    let result=ArrayUtils.updateKey(datas,keys);
    console.log(result);//{name: "张三", sex: "1"}
}
//数组中对象key替换，例如源数据为[{"name":"张三","age":80}]替换为[{"text":"张三","age":80,"ageGroup":"老年人"}];
//这里是根据某些值特征，增加新的属性
testArray(){
    let datas=[{"name":"张三","sex":"1"}];
    let keys={"name":"text"};
    let result=ArrayUtils.updateKey(data,keys,function(){
        if(data["age"]>75){
            return {"ageGroup":"老年人"};
        }
    });
    console.log(result);//[{"text":"张三","age":80,"ageGroup":"老年人"}];
}
//从树状数组中，根据id的值获取节点数据
getTreeNodeById(){
    let data=[{"id":"id-A","type":"1","children":[
                {"id":"id-A01","type":"2","children":[
                    {"id":"id-A01-01","type":"3","children":[
                        {"id":"id-A01-01-01","type":"3-01"}
                    ]},
                    {"id":"id-A01-02","type":"3","children":[
                        {"id":"id-A01-02-01","type":"3-02"}
                    ]}
                ]},
                {"id":"id-A03","type":"3"}
            ]}];
    let item=ArrayUtils.get(data,"id-A01-02-01","id","children");
    console.log(item);//{ id: 'id-A01-02-01', type: '3-02' }
}
```
### 加密
** md5
```
//字符串的加密
import {JsUtilsApi } from "great-jsutils/index";

JsUtilsApi.md5("admin123456")
```

### Base64
```
//字符串的加密、解密
import {Base64 } from "great-jsutils/index";

console.log('base64：',Base64.encode("123"));
console.log('base64：',Base64.decode("MTIz"));
```

### TimeUtils
```
import {TimeUtils } from "great-jsutils/index";

function testTime(){
    console.log("格式化时间（默认的格式化类型）：",TimeUtils.format(new Date));
    //格式化时间（默认的格式化类型）： 2018-09-23 17:18:19

    console.log("格式化时间（根据传入的参数格式）：",TimeUtils.format(new Date,"yyyy-MM-dd hh时"));
    //格式化时间（根据传入的参数格式）： 2018-09-23 17时

    console.log("格式化时间（API提供的类型）：",TimeUtils.format(new Date,TimeUtils.FORMAT_YMD));
    //格式化时间（API提供的类型）： 2018-09-23

    console.log("当天开始、结束时间",TimeUtils.getDayTime());

    console.log("根据传入的数字，正数则往后推，负数则往前推，例如获取昨天时间：",TimeUtils.getDayTime(-1));
    //当天开始、结束时间 { start: '2018-08-31 00:00:00', end: '2018-08-31 24:59:59' }

    console.log("本周开始、结束时间",TimeUtils.getWeekTime());
    //本周开始、结束时间 { start: '2018-09-17 00:00:00', end: '2018-09-23 24:59:59' }

    console.log("上周开始、结束时间",TimeUtils.getWeekTime(-1));
    //上周开始、结束时间 { start: '2018-09-10 00:00:00', end: '2018-09-16 24:59:59' }

    console.log("本月开始、结束时间",TimeUtils.getMonthTime());
    //本月开始、结束时间 { start: '2018-09-01 00:00:00', end: '2018-09-30 24:59:59' }

    console.log("上月开始、结束时间",TimeUtils.getMonthTime(-1));
    //上月开始、结束时间 { start: '2018-08-01 00:00:00', end: '2018-08-31 24:59:59' }

    console.log("本季度开始结束时间",TimeUtils.getSeasonTime());
    //本季度开始结束时间 { start: '2018-07-01 00:00:00', end: '2018-09-30 24:59:59' }

    console.log("本年开始结束时间",TimeUtils.getYearTime());
    //本年开始结束时间 { start: '2018-01-01 00:00:00', end: '2018-12-31 24:59:59' }
}
```

## 正则
```
import {JsUtilsApi, ArrayUtils, Base64, TimeUtils } from "great-jsutils/index";

```

## 字符串
** 删除全部空格
```
import {StringUtils } from "great-jsutils/index";

StringUtils.trim(str);
```